@@ -11,13 +11,16 @@ import fiona.transform
 from django.contrib.auth.models import Group
 from django.contrib.gis.db import models
 from django.contrib.gis.db.models.aggregates import Extent
+from django.contrib.gis.db.models.fields import BaseSpatialField
 from django.contrib.gis.db.models.functions import Transform
 from django.contrib.gis.geos import GEOSException, GEOSGeometry
 from django.contrib.gis.measure import D
+
 try:
     from django.db.models import JSONField
 except ImportError:  # TODO Remove when dropping Django releases < 3.1
     from django.contrib.postgres.fields import JSONField
+from django.contrib.gis.geos import WKBWriter
 from django.contrib.postgres.indexes import GistIndex, GinIndex
 from django.core.serializers import serialize
 from django.db import connection, transaction
@@ -31,9 +34,9 @@ from fiona.crs import from_epsg
 from . import GeometryTypes, settings as app_settings
 from .db.managers import FeatureQuerySet
 from .db.mixins import BaseUpdatableModel, LayerBasedModelMixin
+from .functions import ST_IsEmpty
 from .helpers import ChunkIterator, make_zipfile_bytesio
-from .routing.db.mixins import PgRoutingMixin
-from .routing.decorators import topology_update
+from .routing.mixins import PgRoutingMixin, UpdateRoutingMixin
 from .signals import save_feature, save_layer_relation
 from .tiles.decorators import zoom_update
 from .tiles.funcs import ST_HausdorffDistance
@@ -48,7 +51,7 @@ ACCEPTED_PROJECTIONS = [
 ]
 
 
-class Layer(LayerBasedModelMixin):
+class Layer(LayerBasedModelMixin, UpdateRoutingMixin):
     name = models.CharField(max_length=256, unique=True, default=uuid.uuid4)
     schema = JSONField(default=dict, blank=True, validators=[validate_json_schema])
     authorized_groups = models.ManyToManyField(Group, blank=True, related_name='authorized_layers')
@@ -109,7 +112,6 @@ class Layer(LayerBasedModelMixin):
             Feature.objects.filter(**filter_kwargs)\
                 .update(properties=feature_args["properties"])
 
-    @topology_update
     @zoom_update
     def from_csv_dictreader(self, reader, pk_properties, options, operations,
                             init=False, chunk_size=1000, fast=False):
@@ -137,7 +139,6 @@ class Layer(LayerBasedModelMixin):
                 fast=fast
             )
 
-    @topology_update
     @zoom_update
     def from_geojson(self, geojson_data, id_field=None, update=False):
         """
@@ -243,7 +244,6 @@ class Layer(LayerBasedModelMixin):
         else:
             return fiona.crs.to_string(projection)
 
-    @topology_update
     @zoom_update
     def from_shapefile(self, zipped_shapefile_file, id_field=None):
         ''' Load ShapeFile content provided into a zipped archive.
@@ -400,6 +400,11 @@ class Feature(BaseUpdatableModel, PgRoutingMixin):
 
     objects = Manager.from_queryset(FeatureQuerySet)()
 
+    def save(self, *args, **kwargs):
+        if self.geom.hasz:
+            self.geom = GEOSGeometry(WKBWriter().write(self.geom))
+        super(Feature, self).save(*args, **kwargs)
+
     def get_bounding_box(self):
         return self.geom.extent
 
@@ -462,6 +467,13 @@ class Feature(BaseUpdatableModel, PgRoutingMixin):
                     break
                 FeatureRelation.objects.bulk_create(batch, batch_size)
 
+    @cached_property
+    def relations(self):
+        return {
+            slugify(relation.name): self.relations_as_origin.filter(relation=relation)
+            for relation in self.layer.relations_as_origin.all()
+        }
+
     def clean(self):
         """
         Validate properties according schema if provided
@@ -486,6 +498,8 @@ class Feature(BaseUpdatableModel, PgRoutingMixin):
         constraints = [
             # geometry should be valid
             models.CheckConstraint(check=models.Q(geom__isvalid=True), name='geom_is_valid'),
+            # geometry should not be empty
+            models.CheckConstraint(check=models.Q(geom__isempty=False), name='geom_is_empty')
         ]
 
 
@@ -590,3 +604,8 @@ class FeatureExtraGeom(BaseUpdatableModel):
             GistIndex(name='feg_geom_gist_index', fields=['layer_extra_geom', 'geom']),
             GinIndex(name='feg_properties_gin_index', fields=['properties']),
         ]
+
+
+@BaseSpatialField.register_lookup
+class IsEmpty(ST_IsEmpty):
+    lookup_name = 'isempty'
